@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,8 +36,8 @@ class filter_featureset : public Featureset
 
   public:
     filter_featureset(featureset_ptr const& fs, filter_type&& filter)
-        : fs_(fs)
-        , filter_(std::move(filter))
+        : fs_(fs),
+          filter_(std::move(filter))
     {}
 
     feature_ptr next()
