@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,8 +49,8 @@ struct pair_layout
 {
   public:
     pair_layout(double item_margin = 1.0, double max_difference = -1.0)
-        : item_margin_(item_margin)
-        , max_difference_(max_difference)
+        : item_margin_(item_margin),
+          max_difference_(max_difference)
     {}
 
     double get_item_margin() const { return item_margin_; }
