@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -75,8 +75,8 @@ class MAPNIK_DECL Map : boost::equality_comparable<Map>
     };
 
   private:
-    static const unsigned MIN_MAPSIZE = 16;
-    static const unsigned MAX_MAPSIZE = MIN_MAPSIZE << 10;
+    static unsigned const MIN_MAPSIZE = 16;
+    static unsigned const MAX_MAPSIZE = MIN_MAPSIZE << 10;
     unsigned width_;
     unsigned height_;
     std::string srs_;
