@@ -51,7 +51,7 @@ class csv_inline_featureset : public mapnik::Featureset
     char separator_;
     char quote_;
     std::vector<std::string> headers_;
-    const array_type index_array_;
+    array_type const index_array_;
     array_type::const_iterator index_itr_;
     array_type::const_iterator index_end_;
     mapnik::context_ptr ctx_;
