@@ -36,7 +36,7 @@
 #include <thread>
 
 DATASOURCE_PLUGIN_IMPL(tiles_datasource_plugin, tiles_datasource);
-DATASOURCE_PLUGIN_EXPORT(tiles_datasource_plugin);
+DATASOURCE_PLUGIN_EXPORT(tiles);
 DATASOURCE_PLUGIN_EMPTY_AFTER_LOAD(tiles_datasource_plugin);
 DATASOURCE_PLUGIN_EMPTY_BEFORE_UNLOAD(tiles_datasource_plugin);
 
@@ -51,6 +51,8 @@ tiles_datasource::~tiles_datasource() {}
 
 mapnik::datasource::datasource_t tiles_datasource::type() const
 {
+    if (source_ptr_ && source_ptr_->is_raster())
+        return datasource::Raster;
     return datasource::Vector;
 }
 
@@ -74,88 +76,70 @@ mapnik::box2d<double> tiles_datasource::envelope() const
     return extent_;
 }
 
-void tiles_datasource::init(mapnik::parameters const& params)
+namespace {
+
+boost::json::value const& xyz_metadata(std::string const& url_str)
 {
-    std::optional<std::string> file = params.get<std::string>("file");
-    if (!file)
+    static thread_local std::unordered_map<std::string, boost::json::value> metadata_cache;
+    auto itr = metadata_cache.find(url_str);
+    if (itr == metadata_cache.end())
     {
-        throw mapnik::datasource_exception("Tiles Plugin: missing <file> parameter");
+        auto meta = xyz_tiles::metadata(url_str);
+        auto result = metadata_cache.emplace(url_str, std::move(meta));
+        return result.first->second;
     }
+    return itr->second;
+}
+} // namespace
 
-    std::optional<std::string> base = params.get<std::string>("base");
-    if (base)
+void tiles_datasource::init_metadata(boost::json::value const& metadata)
+{
+    if (!metadata.is_object())
+        return;
+    if (auto const* p = metadata.as_object().if_contains("bounds"))
     {
-        database_path_ = *base + "/" + *file;
-    }
-    else
-    {
-        database_path_ = *file;
-    }
-    if (!mapnik::util::exists(database_path_))
-    {
-        throw mapnik::datasource_exception("Tiles Plugin: " + database_path_ + " does not exist");
-    }
-    if (database_path_.ends_with(".pmtiles"))
-    {
-        source_ptr_ = std::make_shared<mapnik::pmtiles_source>(database_path_);
-    }
-    else if (database_path_.ends_with(".mbtiles"))
-    {
-        source_ptr_ = std::make_shared<mapnik::mbtiles_source>(database_path_);
-    }
-    else
-    {
-        throw mapnik::datasource_exception("Unexpected file extension in tiles source: " + database_path_);
-    }
-
-    if (!source_ptr_->is_raster())
-    {
-        std::optional<std::string> layer = params.get<std::string>("layer");
-        try
+        if (p->is_array())
         {
-            layer_ = layer.value();
-        }
-        catch (std::bad_optional_access&)
-        {
-            throw mapnik::datasource_exception("Tiles Plugin: parameter 'layer' is missing.");
+            auto bounds_array = p->as_array();
+            if (bounds_array.size() == 4)
+            {
+                extent_ = {bounds_array[0].to_number<double>(),
+                           bounds_array[1].to_number<double>(),
+                           bounds_array[2].to_number<double>(),
+                           bounds_array[3].to_number<double>()};
+            }
         }
     }
-
-    minzoom_ = source_ptr_->minzoom();
-    maxzoom_ = source_ptr_->maxzoom();
-    extent_ = source_ptr_->extent();
-    // overwrite envelope with user supplied
-    std::optional<std::string> ext = params.get<std::string>("extent");
-    if (ext && !ext->empty())
+    if (auto const* p = metadata.as_object().if_contains("minzoom"))
     {
-        extent_.from_string(*ext);
+        if (p->is_number())
+            minzoom_ = p->as_int64();
     }
-    if (!extent_.valid())
+    if (auto const* p = metadata.as_object().if_contains("maxzoom"))
     {
-        throw mapnik::datasource_exception("Tiles Plugin: " + database_path_ + " extent is invalid.");
+        if (p->is_number())
+            maxzoom_ = p->as_int64();
     }
-    // Bounds are specified in EPSG:4326, therefore transformation is required.
-    mapnik::lonlat2merc(extent_.minx_, extent_.miny_);
-    mapnik::lonlat2merc(extent_.maxx_, extent_.maxy_);
-
-    auto metadata = source_ptr_->metadata();
-    if (!source_ptr_->is_raster())
+    bool found = false;
+    auto const* layers = metadata.as_object().if_contains("vector_layers");
+    if (layers && layers->is_array() && layer_name_)
     {
-        auto layers = metadata.at("vector_layers");
-        bool found = false;
-        for (auto const& layer : layers.as_array())
+        for (auto const& layer : layers->as_array())
         {
+            is_vector_ = true;
             std::string id = layer.at("id").as_string().c_str();
-            if (id == layer_)
+            if (id == *layer_name_)
             {
                 found = true;
                 if (auto const* p = layer.as_object().if_contains("minzoom"))
                 {
-                    minzoom_ = std::max(minzoom_, p->as_int64());
+                    if (p->is_number())
+                        minzoom_ = p->as_int64();
                 }
                 if (auto const* p = layer.as_object().if_contains("maxzoom"))
                 {
-                    maxzoom_ = std::min(maxzoom_, p->as_int64());
+                    if (p->is_number())
+                        maxzoom_ = p->as_int64();
                 }
                 for (auto const& field : layer.at("fields").as_object())
                 {
@@ -176,11 +160,99 @@ void tiles_datasource::init(mapnik::parameters const& params)
                 break;
             }
         }
-        if (!found)
+    }
+    if (!found && is_vector_ && layer_name_)
+    {
+        throw mapnik::datasource_exception("Requested layer '" + *layer_name_ + "' not found.");
+    }
+}
+
+void tiles_datasource::init(mapnik::parameters const& params)
+{
+    std::optional<std::string> file = params.get<std::string>("file");
+    std::optional<std::string> json_url = params.get<std::string>("url");
+    if (!file && !json_url)
+    {
+        throw mapnik::datasource_exception("Tiles Plugin: missing <file> or <json-url> parameter");
+    }
+
+    layer_name_ = params.get<std::string>("layer");
+
+    if (file)
+    {
+        std::optional<std::string> base = params.get<std::string>("base");
+        if (base)
         {
-            throw mapnik::datasource_exception("Requested layer '" + layer_ + "' not found.");
+            database_path_ = *base + "/" + *file;
+        }
+        else
+        {
+            database_path_ = *file;
+        }
+        if (!mapnik::util::exists(database_path_))
+        {
+            throw mapnik::datasource_exception("Tiles Plugin: " + database_path_ + " does not exist");
+        }
+        if (database_path_.ends_with(".pmtiles"))
+        {
+            source_ptr_ = std::make_shared<mapnik::pmtiles_source>(database_path_);
+        }
+        else if (database_path_.ends_with(".mbtiles"))
+        {
+            source_ptr_ = std::make_shared<mapnik::mbtiles_source>(database_path_);
+        }
+        else
+        {
+            throw mapnik::datasource_exception("Unexpected file extension in tiles source: " + database_path_);
+        }
+
+        minzoom_ = source_ptr_->minzoom();
+        maxzoom_ = source_ptr_->maxzoom();
+        extent_ = source_ptr_->extent();
+        auto metadata = source_ptr_->metadata();
+        init_metadata(metadata);
+    }
+    else if (json_url)
+    {
+        if ((*json_url).ends_with(".json"))
+        {
+            extent_ = mapnik::box2d<double>(-180, -85.0511287, 180, 85.0511287);
+            auto metadata = xyz_metadata(*json_url);
+            init_metadata(metadata);
+            auto tiles = metadata.at("tiles");
+            for (auto const& tiles_url : tiles.as_array())
+            {
+                url_template_ = tiles_url.as_string();
+            }
+        }
+        else
+        {
+            extent_ = mapnik::box2d<double>(-180, -85.0511287, 180, 85.0511287);
+            if ((*json_url).ends_with(".mvt") || (*json_url).ends_with(".pbf"))
+            {
+                is_vector_ = true;
+            }
+            url_template_ = json_url;
         }
     }
+    // overwrite envelope with user supplied
+    std::optional<std::string> ext = params.get<std::string>("extent");
+    if (ext && !ext->empty())
+    {
+        extent_.from_string(*ext);
+    }
+    if (!extent_.valid())
+    {
+        throw mapnik::datasource_exception("Tiles Plugin: " + database_path_ + " extent is invalid.");
+    }
+    // Bounds are specified in EPSG:4326, therefore transformation is required.
+    mapnik::lonlat2merc(extent_.minx_, extent_.miny_);
+    mapnik::lonlat2merc(extent_.maxx_, extent_.maxy_);
+    // overwrite min/max zoom with user supplied values.
+    minzoom_ = *params.get<mapnik::value_integer>("minzoom", minzoom_);
+    maxzoom_ = *params.get<mapnik::value_integer>("maxzoom", maxzoom_);
+    // overwrite default max_threads
+    max_threads_ = *params.get<mapnik::value_integer>("max-threads", max_threads_);
 }
 
 mapnik::context_ptr tiles_datasource::get_context_with_attributes() const
@@ -224,11 +296,7 @@ std::int64_t scale_to_zoom(double scale, std::int64_t minzoom, std::int64_t maxz
     for (std::int64_t zoom = 0; zoom < 22; ++zoom)
     {
         if (scale > std::ceil(scales[zoom]))
-            return std::min(zoom, minzoom);
-        else if (scale < std::ceil(scales[zoom]) && scale > std::ceil(scales[zoom + 1]))
-        {
             return std::min(zoom, maxzoom);
-        }
     }
     return maxzoom;
 }
@@ -236,8 +304,8 @@ std::int64_t scale_to_zoom(double scale, std::int64_t minzoom, std::int64_t maxz
 
 std::unordered_map<std::string, std::string>& tiles_datasource::tile_cache()
 {
-    static thread_local std::unordered_map<std::string, std::string> vector_tile_cache;
-    return vector_tile_cache;
+    static thread_local std::unordered_map<std::string, std::string> tiles_cache;
+    return tiles_cache;
 }
 
 mapnik::featureset_ptr tiles_datasource::features(mapnik::query const& q) const
@@ -245,36 +313,63 @@ mapnik::featureset_ptr tiles_datasource::features(mapnik::query const& q) const
 #ifdef MAPNIK_STATS
     mapnik::progress_timer __stats__(std::clog, "tiles_datasource::features");
 #endif
-    auto& vector_tile_cache = tile_cache();
-    if (vector_tile_cache.size() > 16)
+    auto& tiles_cache = tile_cache();
+    if (tiles_cache.size() > 64)
     {
-        vector_tile_cache.clear();
+        tiles_cache.clear();
     }
-    auto datasource_hash = std::hash<std::string>{}(database_path_);
-    mapnik::box2d<double> bbox = q.get_bbox().intersect(extent_);
-    auto zoom = scale_to_zoom(q.scale_denominator(), minzoom_, maxzoom_);
-    mapnik::context_ptr context = get_query_context(q);
-    if (source_ptr_->is_raster())
+
+    if (q.get_bbox().intersects(extent_))
     {
-        return std::make_shared<raster_tiles_featureset>(source_ptr_,
-                                                         context,
-                                                         zoom,
-                                                         bbox,
-                                                         layer_,
-                                                         vector_tile_cache,
-                                                         datasource_hash,
-                                                         q.get_filter_factor());
-    }
-    else
-    {
-        return std::make_shared<vector_tiles_featureset>(source_ptr_,
-                                                         context,
-                                                         zoom,
-                                                         bbox,
-                                                         layer_,
-                                                         vector_tile_cache,
-                                                         datasource_hash);
+        mapnik::box2d<double> bbox = q.get_bbox().intersect(extent_);
+        auto zoom = scale_to_zoom(q.scale_denominator(), minzoom_, maxzoom_);
+        mapnik::context_ptr context = get_query_context(q);
+
+        int tile_count = 1 << zoom;
+        auto xmin = static_cast<int>((bbox.minx() + mapnik::EARTH_CIRCUMFERENCE / 2) *
+                                     (tile_count / mapnik::EARTH_CIRCUMFERENCE));
+        auto xmax = static_cast<int>((bbox.maxx() + mapnik::EARTH_CIRCUMFERENCE / 2) *
+                                     (tile_count / mapnik::EARTH_CIRCUMFERENCE));
+        auto ymin = static_cast<int>(((mapnik::EARTH_CIRCUMFERENCE / 2) - bbox.maxy()) *
+                                     (tile_count / mapnik::EARTH_CIRCUMFERENCE));
+        auto ymax = static_cast<int>(((mapnik::EARTH_CIRCUMFERENCE / 2) - bbox.miny()) *
+                                     (tile_count / mapnik::EARTH_CIRCUMFERENCE));
+
+        std::string source_location = url_template_ ? *url_template_ : database_path_;
+        auto datasource_hash = std::hash<std::string>{}(source_location);
+
+        if (is_vector_ && layer_name_)
+        {
+            return std::make_shared<vector_tiles_featureset>(source_location,
+                                                             context,
+                                                             zoom,
+                                                             xmin,
+                                                             xmax,
+                                                             ymin,
+                                                             ymax,
+                                                             bbox,
+                                                             *layer_name_,
+                                                             tiles_cache,
+                                                             max_threads_,
+                                                             datasource_hash);
+        }
+        else
+        {
+            return std::make_shared<raster_tiles_featureset>(source_location,
+                                                             context,
+                                                             bbox,
+                                                             zoom,
+                                                             xmin,
+                                                             xmax,
+                                                             ymin,
+                                                             ymax,
+                                                             tiles_cache,
+                                                             max_threads_,
+                                                             datasource_hash,
+                                                             q.get_filter_factor());
+        }
     }
+    return mapnik::featureset_ptr{};
 }
 
 mapnik::featureset_ptr tiles_datasource::features_at_point(mapnik::coord2d const& pt, double tol) const
@@ -285,7 +380,6 @@ mapnik::featureset_ptr tiles_datasource::features_at_point(mapnik::coord2d const
 
     mapnik::filter_at_point filter(pt, tol);
     mapnik::context_ptr context = get_context_with_attributes();
-    auto datasource_hash = std::hash<std::string>{}(database_path_);
     int tile_count = 1 << maxzoom_;
     auto tile_x =
       static_cast<int>((pt.x + mapnik::EARTH_CIRCUMFERENCE / 2) * (tile_count / mapnik::EARTH_CIRCUMFERENCE));
@@ -297,14 +391,25 @@ mapnik::featureset_ptr tiles_datasource::features_at_point(mapnik::coord2d const
     double x1 = (tile_x + 1) * (mapnik::EARTH_CIRCUMFERENCE / tile_count) - 0.5 * mapnik::EARTH_CIRCUMFERENCE;
     double y1 = -(tile_y + 1) * (mapnik::EARTH_CIRCUMFERENCE / tile_count) + 0.5 * mapnik::EARTH_CIRCUMFERENCE;
     auto query_bbox = mapnik::box2d<double>{x0, y0, x1, y1};
-    if (!source_ptr_->is_raster())
-        return std::make_shared<vector_tiles_featureset>(source_ptr_,
+
+    std::string source_location = url_template_ ? *url_template_ : database_path_;
+    auto datasource_hash = std::hash<std::string>{}(source_location);
+
+    if (is_vector_ && layer_name_)
+    {
+        return std::make_shared<vector_tiles_featureset>(source_location,
                                                          context,
                                                          maxzoom_,
+                                                         tile_x,
+                                                         tile_x,
+                                                         tile_y,
+                                                         tile_y,
                                                          query_bbox,
-                                                         layer_,
+                                                         *layer_name_,
                                                          tile_cache(),
+                                                         max_threads_,
                                                          datasource_hash);
+    }
     return mapnik::featureset_ptr();
 }
 
